package com.alihealth.d2d.provtest.service.handle.business;

import com.alihealth.d2d.provtest.domain.DomesticDrugProductionApplyInfo;
import com.alihealth.d2d.provtest.entity.EventBasic;
import com.alihealth.d2d.provtest.entity.EventBody;
import com.alihealth.d2d.provtest.entity.InstanceDetail;
import com.alihealth.d2d.provtest.entity.ItemDetail;
import com.alihealth.d2d.provtest.service.IDomesticDrugProductionApplyInfoService;
import com.alihealth.d2d.provtest.service.handle.AbstractEventDataHandler;
import com.alihealth.d2d.provtest.service.handle.EventSubType;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.text.SimpleDateFormat;

/**
 * @author Jason
 * @date 2025年06月05日 11:14:43
 */
@Service
@EventSubType("2011")
public class SubType2011Handler extends AbstractEventDataHandler<DomesticDrugProductionApplyInfo> {

    @Autowired
    private IDomesticDrugProductionApplyInfoService service;

    @Override
    protected Class<DomesticDrugProductionApplyInfo> getEntityClass() {
        return DomesticDrugProductionApplyInfo.class;
    }

    @Override
    protected IService<DomesticDrugProductionApplyInfo> getService() {
        return service;
    }

    @Override
    protected DomesticDrugProductionApplyInfo convertToEntity(EventBody eventBody, ItemDetail item, InstanceDetail instance) {
        EventBasic evtBasic = eventBody.getEvtBasic();
        //时间格式
        SimpleDateFormat formatterDatetime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        //日期格式
        SimpleDateFormat formatterDate = new SimpleDateFormat("yyyyMMdd");

        try {
            return DomesticDrugProductionApplyInfo.builder()
                    .eventId(eventBody.getEventID())
                    .recTime(formatterDatetime.parse(eventBody.getRecTime()))
                    .rkdbh(evtBasic.getString("RKDBH"))

                    .rksj(formatterDatetime.parse(evtBasic.getString("RKSJ")))

                    .rkdwmc(evtBasic.getString("RKDWMC"))
                    .rkdwtyshxydm(evtBasic.getString("RKDWTYSHXYDM"))
                    .rkdwlx(evtBasic.getString("RKDWLX"))
                    .tyshxydmscqy(item.getString("TYSHXYDMSCQY"))
                    .scqymc(item.getString("SCQYMC"))
                    .yptymc(item.getString("YPTYMC"))
                    .gjypbsm(item.getString("GJYPBSM"))
                    .ymscph(item.getString("YMSCPH"))

                    .scrq(formatterDate.parse(item.getString("SCRQ")))
                    .ymyxqjzrq(formatterDate.parse(item.getString("YMYXQJZRQ")))

                    .scsl(Integer.parseInt(item.getString("SCSL")))
                    .scdz(item.getString("SCDZ"))
                    .ypzsm(instance.getString("YPZSM"))
                    .syjbzypzsm(instance.getString("SYJBZYPZSM"))
                    .bzcj(instance.getString("BZCJ"))
                    .ymzt(instance.getString("YMZT"))
                    .build();
        } catch (ParseException e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public String getSubType() {
        return "2011";
    }

    @Override
    public void handleBase(String xml, String eventId) {

    }

}
